# ActivitiesSummaryV30Rc1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV30Rc1**](LastModifiedDateV30Rc1.md) |  | [optional] 
**distinctions** | [**DistinctionsV30Rc1**](DistinctionsV30Rc1.md) |  | [optional] 
**educations** | [**EducationsSummaryV30Rc1**](EducationsSummaryV30Rc1.md) |  | [optional] 
**employments** | [**EmploymentsSummaryV30Rc1**](EmploymentsSummaryV30Rc1.md) |  | [optional] 
**fundings** | [**FundingsV30Rc1**](FundingsV30Rc1.md) |  | [optional] 
**invited_positions** | [**InvitedPositionsV30Rc1**](InvitedPositionsV30Rc1.md) |  | [optional] 
**memberships** | [**MembershipsV30Rc1**](MembershipsV30Rc1.md) |  | [optional] 
**peer_reviews** | [**PeerReviewsV30Rc1**](PeerReviewsV30Rc1.md) |  | [optional] 
**qualifications** | [**QualificationsV30Rc1**](QualificationsV30Rc1.md) |  | [optional] 
**research_resources** | [**ResearchResourcesV30Rc1**](ResearchResourcesV30Rc1.md) |  | [optional] 
**services** | [**ServicesV30Rc1**](ServicesV30Rc1.md) |  | [optional] 
**works** | [**WorksSummaryV30Rc1**](WorksSummaryV30Rc1.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

